@@ -23,7 +23,10 @@ class ftpFileHelper(QtCore.QObject):
 		self.port = portc
 		
 		self.ftphelper = QFtp(self)
-		self.ftphelper.connectToHost(self.server,  self.port)
+		(portInt,  ok)=self.port.toInt()
+		if not ok:
+			portInt = 21
+		self.ftphelper.connectToHost(self.server,  portInt)
 		self.ftphelper.login(self.login, self.password)
 		
 		self.ftphelper.commandFinished.connect(self.ftpCommandFinished)
