@@ -36,6 +36,7 @@ class XmlBookmark(QtCore.QObject):
 			if not self.file.open(QtCore.QIODevice.ReadWrite):
 				return False
 			ts = QTextStream(self.file)
+			ts.setCodec("UTF-8");
 			ts << self.doc.toString()
 			self.file.close()
 			self.flushFile()
@@ -59,6 +60,7 @@ class XmlBookmark(QtCore.QObject):
 		if not self.file.open(QtCore.QIODevice.WriteOnly):
 			return False
 		ts = QTextStream(self.file)
+		ts.setCodec("UTF-8");
 		ts << self.doc.toString()
 		self.file.close()
 		return True
@@ -131,3 +133,31 @@ class XmlBookmark(QtCore.QObject):
 						return serv
 			domNode = domNode.nextSibling()
 		return Server("",  "",  "",  "", "21")
+		
+	def updateServer(self,  server):
+		domNode = self.root.firstChild()
+		while not domNode.isNull():
+			domElement = domNode.toElement()
+			if not domElement.isNull():
+				if domElement.tagName() == "Server":
+					name = domElement.attribute("name",  "")
+					if name == server.name:
+						domElement.setAttribute("server", server.server)
+						domElement.setAttribute("login",  server.login)
+						domElement.setAttribute("password", server.password)
+						domElement.setAttribute("port",  server.port)
+						break
+			domNode = domNode.nextSibling()
+		self.flushFile()
+
+	def doesBookmarkExist(self,  bookmarkname):
+		domNode = self.root.firstChild()
+		while not domNode.isNull():
+			domElement = domNode.toElement()
+			if not domElement.isNull():
+				if domElement.tagName() == "Server":
+					name = domElement.attribute("name",  "")
+					if name == bookmarkname:
+						return True
+			domNode = domNode.nextSibling()
+		return False
